/****************************************************************************
* Company:		Pertech Industries inc 
* Product:		HOcr
* Module:		DLL OCR recognizer
* File:			HOcrInterface.h
****************************************************************************/


#ifndef HOCRINTERFACE_H
#define HOCRINTERFACE_H

// Types of text/shapes to recognize
#define TYPE_NUMERIC				1		// numeric + punctuation
#define TYPE_SHAPE					2		// Shape recognition
#define TYPE_CMC7					3		// CMC7
#define TYPE_E13B					4		// E13B
#define TYPE_OMNIFONT				5		// omnifont
#define TYPE_PDF417					6		// PDF417
#define TYPE_BARCODE				7		// Barcode (2/5, 3/9 ecc.)
#define TYPE_DATAMATRIX				8		// Datamatrix 2D barcode
#define TYPE_QRCODE					9		// QRCODE 2D barcode
#define TYPE_MICROHOLES				10		// Datamatrix 2D barcode
#define TYPE_USA_MONEY				11		// USA Dollar recognition and Validation
#define TYPE_HANDWRITE				12		// Hand written Chars
#define MAX_PRECO					12		// Max 

// Types of directions
#define LEFT_RIGHT					0		// recognition going left to Right
#define RIGHT_LEFT					1		// recognition going Right to left
#define UP_DOWN						2		// recognition going UP to DOWN
#define DOWN_UP						3		// recognition going DOWN to UP

//-----------------------------------------------------------------------------			

//-----------------------------------------------------------------------------			


// Load in memory and initialize the recognizer specified in Type.
// The function returns TRUE for ok and FALSE for error
// This function is normally called at the beginning of the application. It is possible
// to activate more recognizers in a single session.
extern "C" int FAR PASCAL EXPORT LoadRecognizer(UINT Type);

// Free the memory from all the recognizers loaded. Mandatory to call before the end of the
// application. This function returns TRUE.
extern "C" int FAR PASCAL EXPORT UnloadAllRecognizers(void);

// The input is a DIM in memory (Dib). The function obtain a window (x, y, width, height)
// and on this window the function perform the OCR recognizement. Result is what results
// from the recognizement (ResultSize is the maximum size). The position and the dimensions
// of the window are in 1/10 mm (for example 100 is equal to 10 mm):
//
//       --------------------------                                   |
//       |                        |                   x               |
//       |       OCR window       | <---------------------------------|
//       |                        |                                   |
//       --------------------------                                   |
//                    ^                                               |
//                    |                                               |
//                   y|                                               |
//                    |                            Dib (Bottom Right) |
//      ---------------------------------------------------------------
//
// Type defines the recognizer.
// The return is TRUE for ok and FALSE for error.
extern "C" int FAR PASCAL EXPORT MakeOCR_P(char *DibPtr, 
											int x, int y, int width, int height, 
											UINT Type, UINT direction,
											char *Result, int ResultSize);

// The return is a string with informations about the revision of the DLL
extern "C" char * FAR PASCAL EXPORT GetRecoDllVersion(void);


// ------- Extension ------------

// ChangeType
#define CHANGE_DBG_MODE        1  // used to work in debug mode
#define CHANGE_UNREC_CHAR      2  // change the char used for unrecognized shapes (val is the char)
#define CHANGE_THRESHOLD       3  // change the Threshold level (val is the new threshold level: 0..200; 0=auto)
// val for CHANGE_DEBUG_MODE
#define DBG_NO                 0  // clear all debug mode
#define DBG_SHOWDIB            1  // show the recognized dib

// Change the setup of the recognizer 
extern "C" int FAR PASCAL EXPORT ChangeSetup(long ChangeType, long val);


// HOcrLimitCharset: limit the recognition to the given range of characters.
// Calls to MakeOCRxx will use character set loaded in the last call to HOcrLimitCharset.
// If an empty string is entered entire character set will be used. 
// Valid only for Type = TYPE_OMNIFONT.
extern "C" int FAR PASCAL EXPORT HOcrLimitCharset(const char* char_set);

// Returns a pointer to the DIB (or NULL in case of error)
// FilePath (es: "c:\00001.bmp") is a BMP file (B/W - 16G - 256G)
extern "C" char * FAR PASCAL EXPORT HOcrGetDibPtr(const char *FilePath, long *DIBSize);

// barcode configuration (each char can be a digit - 0 to 9)
//	char 0 -> code 2/5 interleaved conversion
//										0 = disable
//										1 = enable without check digit
//										3 = enable with check digit
//	char 1 -> code 3/9	conversion
//										0 = disable
//										1 = enable without check digit
//										3 = enable with check digit
//	char 2 -> code 128 conversion
//										0 = disable
//										1 = enable without check digit
//	char 3 -> code 93 conversion
//										0 = disable
//										1 = enable without check digit
//	char 4 -> code EAN13 conversion
//										0 = disable
//										1 = enable without check digit
//	char 5 -> code EAN8 conversion
//										0 = disable
//										1 = enable without check digit
//	char 6 -> code UPCA conversion
//										0 = disable
//										1 = enable without check digit
//	char 7 -> code UPCE conversion
//										0 = disable
//										1 = enable without check digit
//	char 8 -> code 3/9 Full conversion
//										0 = disable
//										1 = enable without check digit
//										3 = enable with check digit
// Return: 0 = error, 1 = ok
// Before call this function you must load recognizer (LoadEcognizer())
extern "C" int FAR PASCAL EXPORT HOcrConfigBarcode(const char *cfg);


/****************************************************************
HOcr_SetEnv: Used to override default parameters setup. The parameter EnvType specifies the parameter to override.
The function returns TRUE if setup has completed succesfully, FAlSE if an error has occurred or the EnvType value
is not handled by the function.
	 EnvType = ENV_INIFILENAME
		pNewVal = Pointer to the new inifilename string. If the value is null, the default filename is used.
				Default name is HOcr.ini located in the windows directory
******************************************************************/
extern "C" int FAR PASCAL EXPORT HOcr_SetEnv(UINT EnvType, void * pNewVal);
				// EnvType Declarations

/////////////////////////////////////////////////////////////////////////////
// This function decodes and verify the microholes 
// The input is a BMP file in memory for both front and rear images. 
// The function returns in OutputBuffer string of decoded chars
// The return is TRUE for ok and FALSE for error.
/////////////////////////////////////////////////////////////////////////////
extern "C" int FAR PASCAL EXPORT ValidateMH(UCHAR* FrontImage, UCHAR* RearImage, int x, int y, int width, int height, UCHAR* OutputBuffer);

#define ENV_INIFILENAME		1


#endif